# 筛选达人信息接口文档

## 基本信息
- **接口名称**：筛选达人信息
- **接口URL**：`/api/daren_detail/filter_creators/`
- **请求方式**：GET
- **接口描述**：根据多个条件筛选达人信息，支持分页

## 请求参数
### Query Parameters

| 参数名 | 类型 | 必填 | 说明 | 示例值 |
|--------|------|------|------|---------|
| category | string | 否 | 达人类别 | "Beauty & Personal Care" |
| e_commerce_level | string | 否 | 电商能力等级 | "L1", "L2", "L3" |
| exposure_level | string | 否 | 曝光等级 | "KOC-1", "KOL-1" |
| gmv_range | string | 否 | GMV范围 | "$0-$5k", "$5k-$25k" |
| views_range | string | 否 | 观看量范围 | "0-100", "1k-10k" |
| pricing | string | 否 | 价格过滤 | "$100/video" |
| page | integer | 否 | 页码，默认1 | 1 |
| page_size | integer | 否 | 每页数量，默认10 | 10 |

### GMV范围选项
- "$0-$5k"
- "$5k-$25k"
- "$25k-$50k"
- "$50k-$150k"
- "$150k-$400k"
- "$400k-$1500k"
- "$1500k+"

### 观看量范围选项
- "0-100"
- "1k-10k"
- "10k-100k"
- "100k-250k"
- "250k-500k"
- "500k+"

## 响应参数
```json
{
    "code": 200,
    "message": "获取成功",
    "data": {
        "total_count": 100,        // 总数据量
        "total_pages": 10,         // 总页数
        "current_page": 1,         // 当前页码
        "page_size": 10,           // 每页数量
        "count": 10,               // 当前页数据量
        "creators": [              // 达人列表
            {
                "Creator": {
                    "name": "达人名称",
                    "avatar": "头像URL",
                    "active": true
                },
                "Category": "达人类别",
                "E-commerce Level": "L1",
                "Exposure Level": "KOC-1",
                "Followers": "10k",
                "GMV": "$100k",
                "Items Sold": "1k",
                "Avg. Video Views": "5k",
                "Pricing": {
                    "Indv. P": "个人定价",
                    "Pack. P": "套餐定价"
                },
                "# Collab": 10,
                "Latest Collab.": "最新合作",
                "E-commerce": ["平台1", "平台2"]
            }
        ]
    }
}
```

## 错误响应
```json
{
    "code": 500,
    "message": "筛选达人信息失败: 错误信息",
    "data": null
}
```

## 示例请求
```
GET /api/daren_detail/filter_creators/?category=Beauty&e_commerce_level=L1&gmv_range=$5k-$25k&page=1
```

## 注意事项
1. 所有过滤条件都是可选的，可以组合使用
2. 分页参数默认值：page=1, page_size=10
3. GMV和观看量的范围值需要严格按照文档中提供的选项
4. 电商能力等级格式为"L1"到"L7"
5. 曝光等级格式为"KOC-1", "KOC-2", "KOL-1", "KOL-2", "KOL-3"

## 状态码说明
- 200: 请求成功
- 500: 服务器内部错误 